# -*- coding: utf-8 -*-
#
# Copyright European Organization for Nuclear Research (CERN)
# All rights reserved
#
# Please look at the supplied documentation for the user's
# license
#
# Author: Vasilis.Vlachoudis@cern.ch
# Date:   24-Oct-2018

__author__ = "Vasilis Vlachoudis"
__email__  = "Vasilis.Vlachoudis@cern.ch"

__all__ = [	"Stab",
		"StabCard",
		"StabCardInfo",
		"StabConfig",
		"StabLayout"]

from .input  import Stab
from .card   import StabCard, StabCardInfo
from .layout import StabLayout
from .config import StabConfig

DATABASE     = "db/stab.ini"

#-------------------------------------------------------------------------------
# Initialize classes:
#	StabCardInfo
#	StabParticle
#-------------------------------------------------------------------------------
def init(filename=None, g4name=None, nistname=None):
	import configparser
	from deck import Card, dbpath, readCardini

	Card.register_class(Stab.MODE, StabCard)

	# Load card database
	if filename is None:
		filename = dbpath(DATABASE)

	# read card database and prepare CardInfo classes
	cardini = configparser.RawConfigParser()
	cardini.optionxform = str	# make case sensitive
	if not cardini.read(filename): return False

	# parse cards
	readCardini(cardini, Stab.MODE, StabCardInfo)

	del cardini
	return True

#===============================================================================
# Load only once
init()
