# -*- coding: utf-8 -*-
#
# Copyright European Organization for Nuclear Research (CERN)
# All rights reserved
#
# Please look at the supplied documentation for the user's
# license
#
# Author: Vasilis.Vlachoudis@cern.ch
# Date:   24-Oct-2018

__author__ = "Vasilis Vlachoudis"
__email__  = "Vasilis.Vlachoudis@cern.ch"

from collections import OrderedDict

import log
import Global

from deck    import Input, Card
from .card   import StabCard
from .config import StabConfig

#===============================================================================
# Stab Input class
#===============================================================================
class Stab(Input):
	MODE    = StabCard.MODE
	EXT     = ".stab"		# default extension
	config  = StabConfig()		# configuration information
	defaultMaterials = OrderedDict()

	# ----------------------------------------------------------------------
	def __init__(self):
		super().__init__()
		self.mode       = Stab.MODE
		self.globalDict = StabCard.globalDict

	#-----------------------------------------------------------------------
	# Cards
	#-----------------------------------------------------------------------
	# Return cards of a specific tag sorted with _pos
	# @which	look the Input.cardsSorted()
	# Warning on REGION maybe the "&" you want to get rid off
	#-----------------------------------------------------------------------
	def cardsSorted(self, tag, which=0):
		return super().cardsSorted(tag, which)

	#-----------------------------------------------------------------------
	# Return material list
	#-----------------------------------------------------------------------
	def materialList(self, which=0):
		return super().materialList(which)

	#-----------------------------------------------------------------------
	def materialDict(self):
		matDict = self.defaultMaterials.copy()
		matDict.update(self.cardsSorted(Card.MATERIALS))
		return matDict

	#-----------------------------------------------------------------------
	# Return the region properties as a dictionary of the active/enabled
	# regions
	#-----------------------------------------------------------------------
	def regionProperties(self):
		pass

	#=======================================================================
	# I/O
	# methods for Input IO operations
	#=======================================================================
	#-----------------------------------------------------------------------
	# Export method
	#-----------------------------------------------------------------------
	def _save(self):
		if Global.verbose: log.say("\n*-* Writing stab file")

	#-----------------------------------------------------------------------
	# Import/load a macro and the related moira input files
	#-----------------------------------------------------------------------
	def _load(self):
		if Global.verbose: log.say("\n*-* Reading stab file")

	# ----------------------------------------------------------------------
	# Write an input file to be used for plotting
	# ----------------------------------------------------------------------
	def writePlotgeomInput(self, plotgeom, directory=".", title=""):
		pass
